/* SPDX-FileCopyrightText: 2024 Greenbone AG
 *
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

import {_, type TranslateFunc} from 'gmp/locale/lang';

export type {TranslateFunc};

export default _;
